/* Talika panel applet: Switch between open windows using icons.
 * (C) 2009-2010 Sinew Software Systems
	 *
 * Authors:  Vinod Kumar Dahiya
 *           Hemant Kumar
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
	 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef TALIKA_TASKLIST_H__
#define TALIKA_TASKLIST_H__


#include <gtk/gtk.h>
#include <libwnck/libwnck.h>
#include <panel-applet.h>

#include "xutils.h"


#define N_SCREEN_CONNECTIONS  5

#define POINT_IN_RECT(xcoord, ycoord, rect) \
((xcoord) >= (rect).x &&                   \
(xcoord) <  ((rect).x + (rect).width) &&  \
(ycoord) >= (rect).y &&                   \
(ycoord) <  ((rect).y + (rect).height))

// farword declaration of TalikaTask
struct _TalikaTask;
struct _TalikaClassCache;

// TalikaTaskList data
typedef struct
{
	WnckScreen *screen;
	gint monitor_num;
	GdkRectangle monitor_geometry;
	guint screen_connections[N_SCREEN_CONNECTIONS];

	//taslist main widget
	GtkWidget *box;
		
	GdkPixmap *background;

	// Calculated by update_lists 
	GList *class_groups;
	GList *windows;
	GList *windows_without_class_group;
	GList *visible_tasks;

	// windows with _NET_WM_STATE_SKIP_TASKBAR set; connected to 
	// "state_changed" signal, but excluded from tasklist.
	GList *skipped_windows;

	// windowid -> task hash tables 
	GHashTable *win_hash;
	GHashTable *class_group_hash;

	//currently active task
	struct _TalikaTask *active_class_group;
	struct _TalikaTask *active_task;


	guint activate_timeout_id;

	guint idle_callback_tag;

	guint drag_start_time;

	//gnome panel properties
	guint panel_size;
	PanelAppletOrient panel_orient;

	//general prefrences
	gboolean switch_workspace_on_unminimize;
	gboolean include_all_workspaces;
	gboolean include_all_monitors;
	gboolean use_grouping;
	gboolean group_reverse_order;
	gboolean group_middle_close;

	//icons prefrences
	gboolean button_relief; //no need now,remove it
	gboolean toggle_current_task;
	gboolean dimm_minimised;
	gboolean mono_icons;
	gboolean show_theme_icons;
	gboolean running_indicator;
	
	gint icon_size_offset; // from panel size
	gint button_spacing;

	//preview prefrences
	gboolean enable_previews;
	gboolean previews_group_only;
	gboolean previews_group_click;
	gboolean previews_hide_activation;
	gint preview_rows;
	gint preview_cols;
	guint preview_size;
	guint preview_transparency;  //0 to 10
	guint preview_timeout;
	
	gboolean preview_rounded_corners; //no need remove it
	gboolean preview_reverse_order; //no need remove it

	//colors
	GdkColor running_indicator_color;
	GdkColor preview_popup_bg_color;
	GdkColor preview_popup_fg_color;
	GdkColor preview_win_border_color;
	GdkColor preview_win_title_color;
	
	//preview cache
	TalikaPreviewImageCache *preview_cache;

	//class cache
	struct _TalikaClassCache *class_cache;

	//icon cache
	struct _TalikaIconCache *icon_cache;

	//tooltips stuff
	gboolean cursor_over_icon;
	gboolean hide_delay_started;
	GtkWidget *popup;
	guint enter_timeout_id;
	guint leave_timeout_id;

	//Launchers
	GSList *launchers_ids;
	GList *launchers;

	/**FIXME: Below fields should be in a seprate structure in talika.c.
	 I am a bit lazy to introduce it. */
	
	//gconf applet prefrences listener id, shouldn't be here
	guint gconf_listeners[27];

	//prefrences dialog widgets, shouldn't be here, lazy me
	GtkWidget *properties_dialog;
	GtkWidget *include_all_workspaces_button;
	GtkWidget *include_all_monitors_button;
	
	GtkWidget *group_windows_button;
	GtkWidget *group_reverse_order_button;
	GtkWidget *group_middle_close_button;
	
	GtkWidget *button_relief_button;
	GtkWidget *toggle_current_task_button;
	GtkWidget *dimm_minimised_button;
	GtkWidget *mono_icons_button;
	GtkWidget *show_theme_icons_button;
	GtkWidget *running_indicator_button;
	GtkAdjustment *icon_size_adj;
	GtkAdjustment *button_spacing_adj;
	
	GtkWidget *enable_preview_button;
	GtkWidget *preview_rounded_corners_button;
	GtkWidget *preview_reverse_order_button;
	GtkWidget *previews_group_click_button;
	GtkWidget *previews_group_only_button;
	GtkWidget *previews_hide_activation_button;
	GtkAdjustment *preview_opacity_adj;
	GtkAdjustment *preview_rows_adj;
	GtkAdjustment *preview_cols_adj;
	GtkAdjustment *preview_size_adj;
	GtkAdjustment *preview_timeout_adj;
	GtkWidget *preview_frame;

	GtkWidget *running_indicator_color_button;
	GtkWidget *preview_popup_bg_color_button;
	GtkWidget *preview_popup_fg_color_button;
	GtkWidget *preview_win_border_color_button;
	GtkWidget *preview_win_title_color_button;

	PanelApplet *applet;
}
TalikaTaskList;


/* Tasklist functions
 */

TalikaTaskList *talika_tasklist_new (WnckScreen * screen, guint size,
                                     PanelAppletOrient orient);

void talika_tasklist_free (TalikaTaskList * tasklist);

void talika_tasklist_size_allocation (TalikaTaskList * tasklist, 
                                      int *size_hints);

void talika_tasklist_update_show_all_workspaces (TalikaTaskList * tasklist);

void talika_tasklist_update_group_windows (TalikaTaskList * tasklist);

void talika_tasklist_update_button_relief (TalikaTaskList * tasklist);

void talika_tasklist_update_toggle_current_task (TalikaTaskList * tasklist);

void talika_tasklist_update_dimm_minimised (TalikaTaskList * tasklist);

void talika_tasklist_update_arrows (TalikaTaskList * tasklist);

gboolean talika_tasklist_change_orient (TalikaTaskList * tasklist, 
                                        PanelAppletOrient orient);

void talika_tasklist_update_mono_icons (TalikaTaskList * tasklist);

void talika_tasklist_update_enable_previews (TalikaTaskList * tasklist);

void talika_tasklist_change_active_task (TalikaTaskList * tasklist,
                                         struct _TalikaTask * active_task);

void talika_tasklist_activate_task_window (struct _TalikaTask * task, 
                                           guint32 timestamp, gboolean force_maximize);

void talika_tasklist_update_lists (TalikaTaskList * tasklist);

void talika_tasklist_remove_launcher (struct _TalikaTask *task);

void talika_tasklist_add_launcher (struct _TalikaTask *task);

void talika_tasklist_update_launchers_list (TalikaTaskList *tasklist,
                                            GSList *new_list);

void
talika_tasklist_save_launchers (TalikaTaskList * tasklist);

void 
talika_tasklist_update_visible_states (TalikaTaskList * tasklist);

void 
talika_tasklist_update_button_spacing (TalikaTaskList * tasklist);

void 
talika_tasklist_update_icon_size (TalikaTaskList * tasklist);

#endif /*TALIKA_TASKLIST_H__ */
