/* Talika panel applet: Switch between open windows using icons.
 * (C) 2009-2010 Sinew Software Systems
 *
 * Authors:  Vinod Kumar Dahiya
 *           Hemant Kumar
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef TALIKA_XUTILS_H__
#define TALIKA_XUTILS_H__

#include <glib.h>
#include <X11/Xlib.h>
#include <X11/Xatom.h>
#include <gdk/gdk.h>
#include <gdk/gdkx.h>
#include <libwnck/libwnck.h>
#include <panel-applet.h>

#define TALIKA_STOCK_CLOSE "talika-stock-close"
#define TALIKA_STOCK_MAXIMIZE "talika-stock-maximize"
#define TALIKA_STOCK_MINIMIZE "talika-stock-minimize"
#define TALIKA_STOCK_LAUNCH "talika-stock-launch"
#define TALIKA_STOCK_PIN "talika-stock-pin"
#define TALIKA_STOCK_UNPIN "talika-stock-unpin"
#define TALIKA_STOCK_CHANGE_ICON "talika-stock-change-icon"

#define _wnck_atom_get(atom_name) gdk_x11_get_xatom_by_name (atom_name)
#define _wnck_atom_name(atom)     gdk_x11_get_xatom_name (atom)

void _wnck_error_trap_push (void);
int  _wnck_error_trap_pop  (void);

void xstuff_zoom_animate                (GtkWidget        *widget,
					 GdkPixbuf        *pixbuf,
					 PanelAppletOrient  orientation,
					 GdkRectangle     *opt_src_rect);

GdkPixbuf* talika_get_icon_from_xserver (WnckWindow * window, guint size);

GdkPixbuf* talika_get_window_picture (WnckWindow * window, guint *size);

void _make_gtk_label_bold (GtkLabel * label);

GdkScreen *talika_screen_get_gdk_screen (WnckScreen * screen);

void talika_stock_icons_init (void);

typedef struct
{
	GHashTable *hash;
}
TalikaPreviewImageCache;

TalikaPreviewImageCache* 
talika_preview_image_cache_new(void);

void
talika_preview_image_cache_free(TalikaPreviewImageCache *cache);

void
talika_preview_image_cache_update_window (TalikaPreviewImageCache *cache,
                                          WnckWindow *window,
                                          guint preview_size,
                                          GtkWidget *widget);

GdkPixbuf*
talika_preview_image_cache_get_image (TalikaPreviewImageCache *cache,
                                      WnckWindow *window,
                                      guint *size);

void
talika_preview_image_cache_free_window (TalikaPreviewImageCache *cache,
                                          WnckWindow *window);


#endif
